==> phpunit_12.5.9.orig.tar.xz: phpunit-12.5.9/src/Metadata/DataProvider.php <==
<?php declare(strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace PHPUnit\Metadata;

/**
 * @immutable
 *
 * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
 */
final readonly class DataProvider extends Metadata
{
    /**
     * @var class-string
     */
    private string $className;

    /**
     * @var non-empty-string
     */
    private string $methodName;
    private bool $validateArgumentCount;

    /**
     * @param int<0, 1>        $level
     * @param class-string     $className
     * @param non-empty-string $methodName
     */
    protected function __construct(int $level, string $className, string $methodName, bool $validateArgumentCount)
    {
        parent::__construct($level);

        $this->className             = $className;
        $this->methodName            = $methodName;
        $this->validateArgumentCount = $validateArgumentCount;
    }

    public function isDataProvider(): true
    {
        return true;
    }

    /**
     * @return class-string
     */
    public function className(): string
    {
        return $this->className;
    }

    /**
     * @return non-empty-string
     */
    public function methodName(): string
    {
        return $this->methodName;
    }

    public function validateArgumentCount(): bool
    {
        return $this->validateArgumentCount;
    }
}

==> phpunit_13.0.5.orig.tar.xz: phpunit-13.0.5/src/Metadata/DataProvider.php <==
<?php declare(strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace PHPUnit\Metadata;

/**
 * @immutable
 *
 * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
 */
final readonly class DataProvider extends Metadata
{
    /**
     * @var class-string
     */
    private string $className;

    /**
     * @var non-empty-string
     */
    private string $methodName;
    private bool $validateArgumentCount;

    /**
     * @param class-string     $className
     * @param non-empty-string $methodName
     */
    protected function __construct(Level $level, string $className, string $methodName, bool $validateArgumentCount)
    {
        parent::__construct($level);

        $this->className             = $className;
        $this->methodName            = $methodName;
        $this->validateArgumentCount = $validateArgumentCount;
    }

    public function isDataProvider(): true
    {
        return true;
    }

    /**
     * @return class-string
     */
    public function className(): string
    {
        return $this->className;
    }

    /**
     * @return non-empty-string
     */
    public function methodName(): string
    {
        return $this->methodName;
    }

    public function validateArgumentCount(): bool
    {
        return $this->validateArgumentCount;
    }
}
